[11u] RFR 8217094: HttpClient SSL race if a socket IOException is raised before ALPN is available

Aleksey Shipilev shade at redhat.com
Wed Mar 13 10:12:09 UTC 2019


Hi,

Please review the 11u backport.

Original bug:
  https://bugs.openjdk.java.net/browse/JDK-8217094

Original fix:
  http://hg.openjdk.java.net/jdk/jdk/rev/a47b8125b7cc

The patch applies cleanly, but the test cannot compile due to testlibrary changes.

11u webrev:
  http://cr.openjdk.java.net/~shade/8217094/webrev.11u.01/

It differs from the original version by this:

diff -r 0eca35f9f944 test/jdk/java/net/httpclient/ALPNProxyFailureTest.java
--- a/test/jdk/java/net/httpclient/ALPNProxyFailureTest.java    Wed Jan 16 19:09:16 2019 +0000
+++ b/test/jdk/java/net/httpclient/ALPNProxyFailureTest.java    Wed Mar 13 11:10:47 2019 +0100
@@ -28,6 +28,6 @@
  *          during the handshake.
  * @bug 8217094
  * @library /test/lib http2/server
  * @build jdk.test.lib.net.SimpleSSLContext HttpServerAdapters DigestEchoServer
  *        ALPNFailureTest ALPNProxyFailureTest
  * @modules java.net.http/jdk.internal.net.http.common
@@ -44,5 +44,5 @@
 import javax.net.ServerSocketFactory;
 import javax.net.ssl.SSLContext;
-import jdk.test.lib.net.SimpleSSLContext;
+import jdk.testlibrary.SimpleSSLContext;
 import java.net.InetAddress;
 import java.net.ProxySelector;

Testing: jdk/java/net/httpclient tests, which includes two new regression tests

Thanks,
-Aleksey
@@ -28,6 +28,6 @@
  *          during the handshake.
  * @bug 8217094
- * @library /test/lib http2/server
- * @build jdk.test.lib.net.SimpleSSLContext HttpServerAdapters DigestEchoServer
+ * @library /lib/testlibrary http2/server
+ * @build jdk.testlibrary.SimpleSSLContext HttpServerAdapters DigestEchoServer
  *        ALPNFailureTest ALPNProxyFailureTest
  * @modules java.net.http/jdk.internal.net.http.common



More information about the jdk-updates-dev mailing list